# Pandasaurus

<img src="https://user-images.githubusercontent.com/112839/227489878-d253c381-75fd-4e92-b851-2b36df0fc5ed.png" width=100>

STATUS: BETA

A python library supporting simple queries over ontology annotations in dataframes, using UberGraph queries.

The aim for now is to keep this as a very simple independent Python lib avoiding any complex dependencies.

With the basic library in place, the first planned use for this is as a base for a library that provides simple enrichement and querability to AnnData Cell X Gene matrices following the [CZ single cell curation standard](https://github.com/chanzuckerberg/single-cell-curation/blob/main/schema/3.0.0/schema.md).
